pub unsafe extern "C-unwind" fn IOBluetoothAddSCOAudioDevice(
device: Option<&IOBluetoothDeviceRef>,
config_dict: Option<&CFDictionary>,
) -> c_int👎Deprecated
Available on crate features
IOBluetoothUserLib and objc2-core-foundation only.Expand description
Creates a persistent audio driver that will route audio data to/from the specified device.
In 10.9 this is not needed and does nothing.
Parameter device: A paired Bluetooth audio device
Parameter configDict: Configuration dictionary containing a description of the audio controls to be attached to the driver. Passing NULL will result in default controls
Returns: Returns kIOReturnSuccess if the audio driver was successfully created, error if hardware does not support SCO or device is not paired. On 10.9 it will always return kIOReturnSuccess.