IOBluetoothNSStringToDeviceAddress

Function IOBluetoothNSStringToDeviceAddress 

pub unsafe extern "C-unwind" fn IOBluetoothNSStringToDeviceAddress(
    in_name_string: Option<&NSString>,
    out_device_address: *mut BluetoothDeviceAddress,
) -> c_int
Available on crate features Bluetooth and IOBluetoothUtilities and objc2-foundation only.
Convenience routine to take an NSString and turn it into a BluetoothDeviceAddress structure.

Parameter inNameString: Ptr to an NSString that contains the data to turn into the device address.

Parameter outDeviceAddress: Ptr to an address structure that will be returned.

Returns: Returns success (0) or failure code.

Pass in most types of strings, such as “001122334455” or “00-11-22-33-44-55” and the conversion should be successful. Also, you should have 2 characters per byte for the conversion to work properly.