IOBluetoothOBEXSessionCreateWithIOBluetoothDeviceRefAndChannelNumber

Function IOBluetoothOBEXSessionCreateWithIOBluetoothDeviceRefAndChannelNumber 

pub unsafe extern "C-unwind" fn IOBluetoothOBEXSessionCreateWithIOBluetoothDeviceRefAndChannelNumber(
    in_device_ref: &IOBluetoothDeviceRef,
    in_channel_id: BluetoothRFCOMMChannelID,
    out_session_ref: *mut OBEXSessionRef,
) -> OBEXError
👎Deprecated
Available on crate features Bluetooth and IOBluetoothUserLib and OBEX and OBEXBluetooth only.
Create an OBEX session with a device ref and an RFCOMM channel ID. This allows you to bypass the browser if you already know the SDP information.

Parameter inDeviceRef: A valid IOBluetoothDeviceRef reference.

Parameter inChannelID: A valid RFCOMM channel ID on the target device.

Parameter outSessionRef: A valid ptr to an IOBluetoothOBEXSessionRef; will contain the newly created session if return value is kOBEXSuccess.

Returns: An error code value. 0 if successful.

You will use a session reference to do all OBEX interaction to a specific device. This method DOES NOT create a connection to the device of any kind.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.