IOBluetoothOBEXSessionCreateWithIncomingIOBluetoothRFCOMMChannel

Function IOBluetoothOBEXSessionCreateWithIncomingIOBluetoothRFCOMMChannel 

pub unsafe extern "C-unwind" fn IOBluetoothOBEXSessionCreateWithIncomingIOBluetoothRFCOMMChannel(
    in_rfcomm_channel_ref: &IOBluetoothRFCOMMChannelRef,
    in_callback: OBEXSessionEventCallback,
    in_user_ref_con: *mut c_void,
    out_session_ref: *mut OBEXSessionRef,
) -> OBEXError
👎Deprecated
Available on crate features IOBluetoothUserLib and OBEX and OBEXBluetooth only.
Create an OBEX session with an IOBluetoothRFCOMMchannel. This implies you are creating a OBEX SERVER session that will dole out info to remote Bluetooth clients.

Parameter inRFCOMMChannel: A valid IOBluetoothRFCOMMChannel reference.

Parameter inGetResponseCallback: A callback for Get requests sent to your session by a remote device. Must be a valid function ptr, otherwise why even call this?

Parameter outSessionRef: A valid ptr to an IOBluetoothOBEXSessionRef; will contain the newly created session if return value is kOBEXSuccess.

Returns: An error code value. 0 if successful.

This assumes that the RFCOMM channel you have passed it is already open and ready to transmit data to the session.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.