IOBluetoothOBEXSessionOpenTransportConnection

Function IOBluetoothOBEXSessionOpenTransportConnection 

pub unsafe extern "C-unwind" fn IOBluetoothOBEXSessionOpenTransportConnection(
    in_session_ref: OBEXSessionRef,
    in_callback: IOBluetoothOBEXSessionOpenConnectionCallback,
    in_user_ref_con: *mut c_void,
) -> OBEXError
👎Deprecated
Available on crate features OBEX and OBEXBluetooth only.
Parameter inSessionRef: A valid session reference.

Parameter inCallback: A valid callback.

Parameter inUserRefCon: Optional parameter; can contain anything you wish. Will be returned in your callback just as you passed it.

Returns: An error code value. 0 if successful.

Opens a transport-level connection to a remote target. For example, if you are using a Bluetooth transport, this will establish the baseband/L2CAP/RFCOMM connection to a device. Once the callback is called, the connection will either be opened or have failed with a status code. That status code will most likely have originated from the transport layer being used, so you may receive a Bluetooth error, an IOKit error, etc, but a 0 status should indicate success in all cases.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.