OBEXAddAuthorizationChallengeHeader

Function OBEXAddAuthorizationChallengeHeader 

pub unsafe extern "C-unwind" fn OBEXAddAuthorizationChallengeHeader(
    in_header_data: *const c_void,
    in_header_data_length: u32,
    dict_ref: Option<&CFMutableDictionary>,
) -> OBEXError
Available on crate features OBEX and objc2-core-foundation only.
Add an authorization challenge header to a dictionary of OBEXheaders.

Parameter inHeaderData: bytes you want to put in the authorization challenge header.

Parameter inHeaderDataLength: length of the bytes you want to put in authorization challenge header.

Parameter dictRef: dictionary you have allocated to hold the headers. Make sure it’s mutable.

Returns: Error code, kOBEXSuccess (0) if success.

Authorization Challenge header - OBEX Spec, 2.2.13: Authorization Challenge.