OBEXAddBodyHeader

Function OBEXAddBodyHeader 

pub unsafe extern "C-unwind" fn OBEXAddBodyHeader(
    in_header_data: *const c_void,
    in_header_data_length: u32,
    is_end_of_body: bool,
    dict_ref: Option<&CFMutableDictionary>,
) -> OBEXError
Available on crate features OBEX and objc2-core-foundation only.
Add bytes of data to a dictionary of OBEXheaders.

Parameter inHeaderData: Body header data.

Parameter inHeaderDataLength: Length of Body header data.

Parameter isEndOfBody: Set this flag if you want an end of body header instead of a body header.

Parameter dictRef: dictionary you have allocated to hold the headers. Make sure it’s mutable.

Returns: Error code, kOBEXSuccess (0) if success.

Body,EndOfBody headers - OBEX Spec, 2.2.9: Byte Sequence