OBEXAddConnectionIDHeader

Function OBEXAddConnectionIDHeader 

pub unsafe extern "C-unwind" fn OBEXAddConnectionIDHeader(
    in_header_data: *const c_void,
    in_header_data_length: u32,
    dict_ref: Option<&CFMutableDictionary>,
) -> OBEXError
Available on crate features OBEX and objc2-core-foundation only.
Add bytes representing a connection ID to a dictionary of OBEX headers.

Parameter inHeaderData: Connection ID data. Should be 4 bytes in length only.

Parameter inHeaderDataLength: Length of Connection ID data. This should ONLY be set to equal 4.

Parameter dictRef: dictionary you have allocated to hold the headers. Make sure it’s mutable.

Returns: Error code, kOBEXSuccess (0) if success.

ConnectionID headers - OBEX Spec, 2.2.10: Byte Sequence

** IMPORTANT NOTE: In bluetooth 1.0, using this function will allow you to pass in any value. You should not pass more than 4 bytes ever. In later releases, if the length passed is not 4, a kOBEXBadArgumentError error will be returned. ***