OBEXCreateVCard

Function OBEXCreateVCard 

pub unsafe extern "C-unwind" fn OBEXCreateVCard(
    in_first_name: *const c_void,
    in_first_name_length: u32,
    in_last_name: *const c_void,
    in_last_name_length: u32,
    in_friendly_name: *const c_void,
    in_friendly_name_length: u32,
    in_name_charset: *const c_void,
    in_name_charset_length: u32,
    in_home_phone: *const c_void,
    in_home_phone_length: u32,
    in_work_phone: *const c_void,
    in_work_phone_length: u32,
    in_cell_phone: *const c_void,
    in_cell_phone_length: u32,
    in_fax_phone: *const c_void,
    in_fax_phone_length: u32,
    in_e_mail_address: *const c_void,
    in_e_mail_address_length: u32,
    in_e_mail_address_charset: *const c_void,
    in_e_mail_address_charset_length: u32,
    in_organization: *const c_void,
    in_organization_length: u32,
    in_organization_charset: *const c_void,
    in_organization_charset_length: u32,
    in_title: *const c_void,
    in_title_length: u32,
    in_title_charset: *const c_void,
    in_title_charset_length: u32,
) -> Option<CFRetained<CFData>>
👎Deprecated
Available on crate features OBEX and objc2-core-foundation only.
Creates a formatted vCard, ready to be sent over OBEX or whatever.

Parameter inNameCharset: A pointer to the charset data used for the name. Pass in a #defined charset for ease of use.

Parameter inNameCharsetLength: Length of name charset assed in above.

Parameter inFirstName: Pointer to data with Person’s first name.

Parameter inFirstNameLength: Length of Person’s first name passed in above.

Parameter inLastName: Pointer to data with Person’s last name.

Parameter inLastNameLength: Length of Person’s last name passed in above.

Parameter inFriendlyName: Pointer to data with Person’s Friendly name.

Parameter inFriendlyNameLength: Length of Person’s Friendly name passed in above.

Parameter inHomePhone: Pointer to data with Person’s Home phone number.

Parameter inHomePhoneLength: Length of Person’s Home phone number passed in above.

Parameter inWorkPhone: Work phone number.

Parameter inWorkPhoneLength: Length of Person’s Work phone number passed in above.

Parameter inCellPhone: Cell phone number.

Parameter inCellPhoneLength: Length of Person’s Cell phone number passed in above.

Parameter inFaxPhone: Fax phone number.

Parameter inFaxPhoneLength: Length of Person’s Fax phone number passed in above.

Parameter inEMailAddress: EMailAddress of person.

Parameter inEMailAddressLength: Length of Person’s EMailAddress passed in above.

Parameter inEMailAddressCharset: Charset of EMailAddress of person.

Parameter inEMailAddressCharsetLength: Length of Person’s EMailAddress charset passed in above.

Parameter inOrganization: Pointer to Organization/business data.

Parameter inOrganizationLength: Length of Organization/business data.

Parameter inOrganizationCharset: Pointer to the charset the Organization/business is in.

Parameter inOrganizationCharsetLength: Length of data for the Organization/business charset.

Parameter inTitle: Pointer to data with Title of person in biz/org.

Parameter inTitleLength: Length of Title of person in biz/org.

Parameter inTitleCharset: Pointer to the charset the Title is in.

Parameter inTitleCharsetLength: Length of data for the Title charset.

Returns: An CFDataRef containing the compiled data. nil if we failed.

All parameters are optional. The CFDataRef returned to you is NOT retained. Retain it if you want to keep it.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.