OBEXSessionDisconnect

Function OBEXSessionDisconnect 

pub unsafe extern "C-unwind" fn OBEXSessionDisconnect(
    in_session_ref: OBEXSessionRef,
    in_optional_headers: *mut c_void,
    in_optional_headers_length: usize,
    in_callback: OBEXSessionEventCallback,
    in_user_ref_con: *mut c_void,
) -> OBEXError
👎Deprecated
Available on crate feature OBEX only.
Send a disconnect command to a remote OBEX server.

Parameter inSessionRef: A valid session reference.

Parameter inOptionalHeaders: Ptr to optional headers you can supply to the command. DO NOT dispose of this pointer until you callback is called with a success.

Parameter inOptionalHeadersLength: Size of data at the specified ptr.

Parameter inCallback: A valid callback. Will be called for progress, errors and completion.

Parameter inUserRefCon: Optional parameter; can contain anything you wish. Will be returned in your callback just as you passed it.

Returns: An error code value. 0 if successful.

As all commands for OBEX sessions, this command is asynchronous only. A NULL callback paramter will result in an error.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.