pub unsafe extern "C-unwind" fn OBEXSessionGet(
in_session_ref: OBEXSessionRef,
in_is_final_chunk: bool,
in_headers_data: *mut c_void,
in_headers_data_length: usize,
in_callback: OBEXSessionEventCallback,
in_user_ref_con: *mut c_void,
) -> OBEXErrorOBEX only.Expand description
Send a get command to a remote OBEX server.
Parameter inSessionRef: A valid session reference.
Parameter inIsFinalChunk: TRUE or FALSE - is this the last chunk of header data for this GET.
Parameter inHeadersData: Headers containing data to GET.
Parameter inHeadersDataLength: Size of header data.
Parameter inCallback: A valid callback. Will be called for progress, errors and completion.
Parameter inUserRefCon: Optional parameter; can contain anything you wish. Will be returned in your callback
just as you passed it.
Returns: An error code value. 0 if successful.
As all commands for OBEX sessions, this command is asynchronous only. A NULL callback paramter will result in an error.
** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.