OBEXSessionSetServerCallback

Function OBEXSessionSetServerCallback 

pub unsafe extern "C-unwind" fn OBEXSessionSetServerCallback(
    in_session_ref: OBEXSessionRef,
    in_callback: OBEXSessionEventCallback,
    in_user_ref_con: *mut c_void,
) -> OBEXError
👎Deprecated
Available on crate feature OBEX only.
Parameter inSessionRef: A valid session reference.

Parameter inCallback: A valid callback. Will be called for progress, errors and completion by server sessions only.

Parameter inUserRefCon: Optional parameter; can contain anything you wish. Will be returned in your callback just as you passed it.

Returns: An error code value. 0 if successful.

Sets callback to be used when an event occurs on an OBEXSession. This is important for OBEX servers, as you will need a way to be called back when the first command is sent to you. So, be sure to set yourself up to listen for events when you are ready to receive them.

** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.