IOBluetoothDevicePair

Struct IOBluetoothDevicePair 

#[repr(C)]
pub struct IOBluetoothDevicePair { /* private fields */ }
Available on crate features IOBluetoothDevicePair and objc2 only.
An instance of IOBluetoothDevicePair represents a pairing attempt to a remote Bluetooth device.

Use the IOBluetoothDevicePair object to attempt to pair with any Bluetooth device. Once -start is invoked on it, progress is returned to the delegate via the messages defined below. This object enables you to pair with devices within your application without having to use the standard panels provided by the IOBluetoothUI framework, allowing you to write custom UI to select devices, and still handle the ability to perform device pairings.

Of note is that this object MAY attempt to perform two low-level pairings, depending on the type of device you are attempting to pair. This is inconsequential to your code, however, as it occurs automatically and does not change the messaging.

Once started, the pairing can be stopped. This will set the delegate to nil and then attempt to disconnect from the device if already connected.

See also Apple’s documentation

Implementations

Source

impl IOBluetoothDevicePair

pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>

pub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>)

This is a weak property. Setter for delegate.

pub unsafe fn pairWithDevice( device: Option<&IOBluetoothDevice>, ) -> Option<Retained<Self>>

Available on crate features IOBluetoothDevice and IOBluetoothObject only.

Creates an autorelease IOBluetoothDevicePair object with a device as the pairing target.

Parameter device: An IOBluetoothDevice to attept to pair with. The device is retained.

Returns: Returns an IOReturn or Bluetooth error code, if the pairing could not be started.

pub unsafe fn start(&self) -> c_int

Kicks off the pairing with the device.

Returns: Returns an IOReturn or Bluetooth error code, if the pairing could not be started.

pub unsafe fn stop(&self)

Stops the current pairing. Removes the delegate and disconnects if device was connected.

pub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>

Available on crate features IOBluetoothDevice and IOBluetoothObject only.

Get the IOBluetoothDevice being used by the object.

Returns: device The IOBluetoothDevice object that the IOBluetoothDevicePair object is pairing with, as specified in -setDevice: or pairWithDevice:

pub unsafe fn setDevice(&self, in_device: Option<&IOBluetoothDevice>)

Available on crate features IOBluetoothDevice and IOBluetoothObject only.

Set the device object to pair with. It is retained by the object.

Parameter device: The IOBluetoothDevice object that the IOBluetoothDevicePair object with which to perform a pairing.

pub unsafe fn replyPINCode_PINCode( &self, pin_code_size: c_ulong, pin_code: *mut BluetoothPINCode, )

Available on crate feature Bluetooth only.

This is the required reply to the devicePairingPINCodeRequest delegate message. Set the PIN code to use during pairing if required.

Parameter PINCodeSize: The PIN code length in octets (8 bits).

Parameter PINcode: PIN code for the device. Can be up to a maximum of 128 bits.

pub unsafe fn replyUserConfirmation(&self, reply: bool)

This is the required reply to the devicePairingUserConfirmationRequest delegate message.

Parameter reply: A yes/no answer provide by the user to the numeric comparison presented.

Source

impl IOBluetoothDevicePair

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}