#[repr(C)]pub struct IOBluetoothDeviceSearchDeviceAttributes {
pub address: BluetoothDeviceAddress,
pub name: BluetoothDeviceName,
pub serviceClassMajor: BluetoothServiceClassMajor,
pub deviceClassMajor: BluetoothDeviceClassMajor,
pub deviceClassMinor: BluetoothDeviceClassMinor,
}Available on crate features
Bluetooth and IOBluetoothUserLib only.Expand description
Structure used to search for particular devices.
Make sure you specify all fields! If you do not set deviceClassMajor for example, and the value is 0, that is mapped to kBluetoothDeviceClassMajorMiscellaneous, which is probably not what you want. To search for all device types, you must pass kBluetoothDeviceClassMajorAny and its relatives.
See also Apple’s documentation
Fields
address: BluetoothDeviceAddressname: BluetoothDeviceNameserviceClassMajor: BluetoothServiceClassMajordeviceClassMajor: BluetoothDeviceClassMajordeviceClassMinor: BluetoothDeviceClassMinorTrait Implementations
Sourceimpl Clone for IOBluetoothDeviceSearchDeviceAttributes
impl Clone for IOBluetoothDeviceSearchDeviceAttributes
Sourcefn clone(&self) -> IOBluetoothDeviceSearchDeviceAttributes
fn clone(&self) -> IOBluetoothDeviceSearchDeviceAttributes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Encode for IOBluetoothDeviceSearchDeviceAttributes
Available on crate feature objc2 only.
impl Encode for IOBluetoothDeviceSearchDeviceAttributes
Available on crate feature
objc2 only.Sourceimpl PartialEq for IOBluetoothDeviceSearchDeviceAttributes
impl PartialEq for IOBluetoothDeviceSearchDeviceAttributes
Sourcefn eq(&self, other: &IOBluetoothDeviceSearchDeviceAttributes) -> bool
fn eq(&self, other: &IOBluetoothDeviceSearchDeviceAttributes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for IOBluetoothDeviceSearchDeviceAttributes
Available on crate feature objc2 only.
impl RefEncode for IOBluetoothDeviceSearchDeviceAttributes
Available on crate feature
objc2 only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for IOBluetoothDeviceSearchDeviceAttributes
impl StructuralPartialEq for IOBluetoothDeviceSearchDeviceAttributes