pub struct IOBluetoothHandsFree { /* private fields */ }IOBluetoothHandsFree only.Expand description
Hands free profile class.
Superclass of IOBluetoothHandsFreeDevice and IOBluetoothHandsFreeAudioGateway classes. Contains the common code used to support the bluetoooth hands free profile.
IOBluetoothHandsFreeDevice
IOBluetoothHandsFreeAudioGateway
See also Apple’s documentation
Implementations
Sourceimpl IOBluetoothHandsFree
impl IOBluetoothHandsFree
Sourcepub unsafe fn supportedFeatures(&self) -> u32
Available on crate feature objc2 only.
pub unsafe fn supportedFeatures(&self) -> u32
objc2 only.Return supported features
Returns the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Returns: The supported features bitmap
Set the supported features
Sets the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Parameter featuresBitmap: The features bitmap
Sourcepub unsafe fn setSupportedFeatures(&self, supported_features: u32)
Available on crate feature objc2 only.
pub unsafe fn setSupportedFeatures(&self, supported_features: u32)
objc2 only.Setter for supportedFeatures.
Sourcepub unsafe fn inputVolume(&self) -> c_float
Available on crate feature objc2 only.
pub unsafe fn inputVolume(&self) -> c_float
objc2 only.Return the input volume
Returns the input volume between 0 and 1. 0 is the same as mute.
Returns: The input volume
Set the input volume
Sets the input volume between 0 and 1. 0 is the same as mute.
Parameter newVolume: The new input volume
Sourcepub unsafe fn setInputVolume(&self, input_volume: c_float)
Available on crate feature objc2 only.
pub unsafe fn setInputVolume(&self, input_volume: c_float)
objc2 only.Setter for inputVolume.
Sourcepub unsafe fn isInputMuted(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isInputMuted(&self) -> bool
objc2 only.Return the input mute state.
Returns the inputs mute state.
Returns: YES if muted; otherwise NO.
Set the input mute state.
Sets the inputs mute state.
Parameter muted: YES if muted; otherwise NO.
Sourcepub unsafe fn setInputMuted(&self, input_muted: bool)
Available on crate feature objc2 only.
pub unsafe fn setInputMuted(&self, input_muted: bool)
objc2 only.Setter for isInputMuted.
Sourcepub unsafe fn outputVolume(&self) -> c_float
Available on crate feature objc2 only.
pub unsafe fn outputVolume(&self) -> c_float
objc2 only.Return the output volume
Returns the output volume between 0 and 1. 0 is the same as mute.
Returns: The output volume
Set the output volume
Sets the output volume between 0 and 1. 0 is the same as mute.
Parameter newVolume: The new output volume
Sourcepub unsafe fn setOutputVolume(&self, output_volume: c_float)
Available on crate feature objc2 only.
pub unsafe fn setOutputVolume(&self, output_volume: c_float)
objc2 only.Setter for outputVolume.
Sourcepub unsafe fn isOutputMuted(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isOutputMuted(&self) -> bool
objc2 only.Return the output mute state.
Returns the outputs mute state.
Returns: YES if muted; otherwise NO.
Set the output mute state.
Sets the outputs mute state.
Parameter muted: YES if muted; otherwise NO.
Sourcepub unsafe fn setOutputMuted(&self, output_muted: bool)
Available on crate feature objc2 only.
pub unsafe fn setOutputMuted(&self, output_muted: bool)
objc2 only.Setter for isOutputMuted.
Sourcepub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>
Available on crate features objc2 and IOBluetoothDevice and IOBluetoothObject only.
pub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>
objc2 and IOBluetoothDevice and IOBluetoothObject only.Return the IOBluetoothDevice.
Returns the IOBluetoothDevice to connect with.
Returns: The IOBluetoothDevice object
Sourcepub unsafe fn deviceSupportedFeatures(&self) -> u32
Available on crate feature objc2 only.
pub unsafe fn deviceSupportedFeatures(&self) -> u32
objc2 only.Return the device’s supported features.
Returns the device’s supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Returns: The device features bitmap
Sourcepub unsafe fn deviceSupportedSMSServices(&self) -> u32
Available on crate feature objc2 only.
pub unsafe fn deviceSupportedSMSServices(&self) -> u32
objc2 only.Return the device’s supported SMS services.
Returns the device’s supported SMS services bitmap. The values are described in “IOBluetoothHandsFreeSMSSupport.”
Returns: The SMS services supported
Sourcepub unsafe fn deviceCallHoldModes(&self) -> u32
Available on crate feature objc2 only.
pub unsafe fn deviceCallHoldModes(&self) -> u32
objc2 only.Return the device’s supported call hold modes.
Returns the device’s supported call hold modes bitmap. The values are described in “IOBluetoothHandsFreeCallHoldModes.”
Returns: The SMS services supported
Sourcepub unsafe fn SMSMode(&self) -> IOBluetoothSMSMode
Available on crate feature objc2 only.
pub unsafe fn SMSMode(&self) -> IOBluetoothSMSMode
objc2 only.Return the device’s SMS mode.
Returns the device’s SMS mode. The values are described in “IOBluetoothSMSMode.”
Returns: The SMS mode
Sourcepub unsafe fn isSMSEnabled(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isSMSEnabled(&self) -> bool
objc2 only.Return YES if the device has SMS enabled.
Returns YES if the device has SMS enabled (by responding to a CMGF command). NO if the device has not set an SMS mode or doesn’t support SMS.
Returns: YES if the device has SMSEnabled; otherwise, NO.
Sourcepub unsafe fn delegate(
&self,
) -> Option<Retained<ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>>
Available on crate feature objc2 only.
pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>>
objc2 only.Return the delegate
Returns the hands free object’s delegate.
Returns: The delegate for the hands free object or nil if it doesn’t have a delegate.
Sets the hands free object’s delegate to a given object or removes an existing delegate.
A IOBluetoothHandsFree delegate can optionally respond to any of the delegate methods in IOBluetoothHandsFreeDelegate and any subclasses delegates.
Parameter newDelegate: The delegate for the hands free object. Pass nil to remove an existing delegate.
Safety
This is not retained internally, you must ensure the object is still alive.
Sourcepub unsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>,
)
Available on crate feature objc2 only.
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>, )
objc2 only.Sourcepub unsafe fn indicator(&self, indicator_name: Option<&NSString>) -> c_int
Available on crate features objc2 and objc2-foundation only.
pub unsafe fn indicator(&self, indicator_name: Option<&NSString>) -> c_int
objc2 and objc2-foundation only.Return an indicator’s value
Returns an indicator’s value.
Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.
Safety
indicator_name might not allow None.
Sourcepub unsafe fn setIndicator_value(
&self,
indicator_name: Option<&NSString>,
indicator_value: c_int,
)
Available on crate features objc2 and objc2-foundation only.
pub unsafe fn setIndicator_value( &self, indicator_name: Option<&NSString>, indicator_value: c_int, )
objc2 and objc2-foundation only.Set an indicator’s value
Sets an indicator’s value.
Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.
Parameter indicatorValue: Will set the indicator value as long as it is within the min and max values allowed.
Safety
indicator_name might not allow None.
Sourcepub unsafe fn initWithDevice_delegate(
this: Allocated<Self>,
device: Option<&IOBluetoothDevice>,
in_delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>,
) -> Option<Retained<Self>>
Available on crate features objc2 and IOBluetoothDevice and IOBluetoothObject only.
pub unsafe fn initWithDevice_delegate( this: Allocated<Self>, device: Option<&IOBluetoothDevice>, in_delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>, ) -> Option<Retained<Self>>
objc2 and IOBluetoothDevice and IOBluetoothObject only.Create a new IOBluetoothHandsFree object
This method should be called on a subclass (IOBluetoothHandsFreeDevice or IOBluetoothHandsFreeAudioGateway) to get full functionality.
Parameter device: An IOBluetoothDevice
Parameter inDelegate: An object to act as delegate that implements the IOBluetoothHandsFreeDelegate protocol.
Returns: A newly created IOBluetoothHandsFreeAudioGateway object on success, nil on failure
Safety
devicemight not allowNone.in_delegatemight not allowNone.
Sourcepub unsafe fn connect(&self)
Available on crate feature objc2 only.
pub unsafe fn connect(&self)
objc2 only.Connect to the device
Connects to the device and sets up a service level connection (RFCOMM channel). Delegate methods will be called once the connection is complete or a failure occurs.
Sourcepub unsafe fn disconnect(&self)
Available on crate feature objc2 only.
pub unsafe fn disconnect(&self)
objc2 only.Disconnect from the device
Disconnects from the device, closes the SCO and service level connection if they are connected. Delegate methods will be called once the disconnection is complete.
Sourcepub unsafe fn isConnected(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isConnected(&self) -> bool
objc2 only.Determine if there is a serivice level connection to the device
Determines if there is a serivice level connection to the device.
Returns: YES if there is a serivice level connection to the device; otherwise, NO.
Sourcepub unsafe fn connectSCO(&self)
Available on crate feature objc2 only.
pub unsafe fn connectSCO(&self)
objc2 only.Open a SCO connection with the device
Opens a SCO connection with the device. The device must already have a service level connection or this will return immediately. Delegate methods will be called once the connection is complete of a failure occurs.
Sourcepub unsafe fn disconnectSCO(&self)
Available on crate feature objc2 only.
pub unsafe fn disconnectSCO(&self)
objc2 only.Disconnect the SCO connection with the device
Disconnects the SCO connection with the device (if one exists). Delegate methods will be called once the disconnection is complete.
Sourcepub unsafe fn isSCOConnected(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isSCOConnected(&self) -> bool
objc2 only.Determine if there is a SCO connection to the device
Determines if there is a SCO connection to the device.
Returns: YES if there is a SCO connection to the device; otherwise, NO.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl AsRef<AnyObject> for IOBluetoothHandsFree
objc2 only.Sourceimpl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFree
objc2 only.Sourceimpl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeAudioGateway
Available on crate features IOBluetoothHandsFreeAudioGateway and objc2 only.
impl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeAudioGateway
IOBluetoothHandsFreeAudioGateway and objc2 only.Sourcefn as_ref(&self) -> &IOBluetoothHandsFree
fn as_ref(&self) -> &IOBluetoothHandsFree
Sourceimpl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
Available on crate features IOBluetoothHandsFreeDevice and objc2 only.
impl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
IOBluetoothHandsFreeDevice and objc2 only.Sourcefn as_ref(&self) -> &IOBluetoothHandsFree
fn as_ref(&self) -> &IOBluetoothHandsFree
Sourceimpl AsRef<NSObject> for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl AsRef<NSObject> for IOBluetoothHandsFree
objc2 only.Sourceimpl Borrow<AnyObject> for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Borrow<AnyObject> for IOBluetoothHandsFree
objc2 only.Sourceimpl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeAudioGateway
Available on crate features IOBluetoothHandsFreeAudioGateway and objc2 only.
impl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeAudioGateway
IOBluetoothHandsFreeAudioGateway and objc2 only.Sourcefn borrow(&self) -> &IOBluetoothHandsFree
fn borrow(&self) -> &IOBluetoothHandsFree
Sourceimpl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
Available on crate features IOBluetoothHandsFreeDevice and objc2 only.
impl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
IOBluetoothHandsFreeDevice and objc2 only.Sourcefn borrow(&self) -> &IOBluetoothHandsFree
fn borrow(&self) -> &IOBluetoothHandsFree
Sourceimpl Borrow<NSObject> for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Borrow<NSObject> for IOBluetoothHandsFree
objc2 only.Sourceimpl ClassType for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl ClassType for IOBluetoothHandsFree
objc2 only.Sourceconst NAME: &'static str = "IOBluetoothHandsFree"
const NAME: &'static str = "IOBluetoothHandsFree"
Sourcetype ThreadKind = <<IOBluetoothHandsFree as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<IOBluetoothHandsFree as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Debug for IOBluetoothHandsFree
objc2 only.Sourceimpl Deref for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Deref for IOBluetoothHandsFree
objc2 only.Sourceimpl Hash for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Hash for IOBluetoothHandsFree
objc2 only.Sourceimpl Message for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl Message for IOBluetoothHandsFree
objc2 only.Sourceimpl NSObjectProtocol for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl NSObjectProtocol for IOBluetoothHandsFree
objc2 only.Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl PartialEq for IOBluetoothHandsFree
objc2 only.Sourceimpl RefEncode for IOBluetoothHandsFree
Available on crate feature objc2 only.
impl RefEncode for IOBluetoothHandsFree
objc2 only.Sourceconst ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSObject as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for IOBluetoothHandsFree
objc2 only.impl Eq for IOBluetoothHandsFree
objc2 only.