IOBluetoothHostController

Struct IOBluetoothHostController 

pub struct IOBluetoothHostController { /* private fields */ }
Available on crate feature IOBluetoothHostController only.
This class is a representation of a Bluetooth Host Controller Interface that is present on the local computer (either plugged in externally or available internally).

This object can be used to ask a Bluetooth HCI for certain pieces of information, and be used to make it perform certain functions.

See also Apple’s documentation

Implementations

Source

impl IOBluetoothHostController

pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>

Available on crate feature objc2 only.
pub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>)

Available on crate feature objc2 only.

Setter for delegate.

This is a weak property.

Safety
  • delegate should be of the correct type.
  • delegate might not allow None.
pub unsafe fn defaultController() -> Option<Retained<Self>>

Available on crate feature objc2 only.

Gets the default HCI controller object.

Returns: A (autoreleased) pointer to the created IOBluetoothHostController object.

pub unsafe fn powerState(&self) -> BluetoothHCIPowerState

Available on crate features objc2 and Bluetooth only.

Gets the controller power state

Returns: The current controller’s power state. This will be 1 for on, or 0 for off. Only Apple Bluetooth adapters support power off

pub unsafe fn classOfDevice(&self) -> BluetoothClassOfDevice

Available on crate features objc2 and Bluetooth only.

Gets the current class of device value.

Returns: Returns the current class of device value.

pub unsafe fn setClassOfDevice_forTimeInterval( &self, class_of_device: BluetoothClassOfDevice, seconds: NSTimeInterval, ) -> c_int

Available on crate features objc2 and Bluetooth and objc2-foundation only.

Sets the current class of device value, for the specified amount of time. Note that the time interval must be set and valid. The range of acceptable values is 30-120 seconds. Anything above or below will be rounded up, or down, as appropriate.

Returns: Returns the whether setting the class of device value was successful. 0 if success, error code otherwise.

pub unsafe fn addressAsString(&self) -> Option<Retained<NSString>>

Available on crate features objc2 and objc2-foundation only.

Convience routine to get the HCI controller’s Bluetooth address as an NSString object.

Returns: Returns NSString *. nil if the address could not be retrieved.

pub unsafe fn nameAsString(&self) -> Option<Retained<NSString>>

Available on crate features objc2 and objc2-foundation only.

Gets the “friendly” name of HCI controller.

Returns: Returns NSString with the device name, nil if there is not one or it cannot be read.

Source

impl IOBluetoothHostController

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Available on crate feature objc2 only.
pub unsafe fn new() -> Retained<Self>

Available on crate feature objc2 only.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}