IOBluetoothL2CAPChannelRef

Struct IOBluetoothL2CAPChannelRef 

pub struct IOBluetoothL2CAPChannelRef { /* private fields */ }
Available on crate feature IOBluetoothUserLib only.
Implementations

Source

impl IOBluetoothL2CAPChannelRef

pub unsafe fn register_for_channel_close_notification( &self, callback: IOBluetoothUserNotificationCallback, in_ref_con: *mut c_void, ) -> Option<CFRetained<IOBluetoothUserNotificationRef>>

Available on crate feature objc2-core-foundation only.

Allows a client to register for a channel close notification.

The given callback will be called when the L2CAP channel is closed.

Parameter channel: The target L2CAP channel

Parameter callback: Callback to be called when the L2CAP channel is closed.

Parameter inRefCon: Client-supplied refCon to be passed to the callback.

Returns: Returns an IOBluetoothUserNotificationRef representing the outstanding L2CAP channel close notification. To unregister the notification, call IOBluetoothUserNotificationUnregister(void) with the returned IOBluetoothUserNotificationRef. If an error is encountered creating the notification, NULL is returned. The returned IOBluetoothUserNotificationRef will be valid for as long as the notification is registered. It is not necessary to retain the result. Once the notification is unregistered, it will no longer be valid.

Safety
  • callback must be implemented correctly.
  • in_ref_con must be a valid pointer.

Methods from Deref<Target = CFType>

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: ConcreteType,

Attempt to downcast the type to that of type T.

This is the reference-variant. Use CFRetained::downcast if you want to convert a retained type. See also ConcreteType for more details on which types support being converted to.

pub fn retain_count(&self) -> usize

Get the reference count of the object.

This function may be useful for debugging. You normally do not use this function otherwise.

Beware that some things (like CFNumbers, small CFStrings etc.) may not have a normal retain count for optimization purposes, and can return usize::MAX in that case.