pub struct IOBluetoothRFCOMMChannel { /* private fields */ }IOBluetoothObject and IOBluetoothRFCOMMChannel only.Expand description
An instance of this class represents an rfcomm channel as defined by the Bluetooth SDP spec..
An RFCOMM channel object can be obtained by opening an rfcomm channel in a device, or by requesting a notification when a channel is created (this is commonly used to provide services).
See also Apple’s documentation
Implementations
Sourceimpl IOBluetoothRFCOMMChannel
impl IOBluetoothRFCOMMChannel
Sourcepub unsafe fn registerForChannelOpenNotifications_selector(
object: Option<&AnyObject>,
selector: Option<Sel>,
) -> Option<Retained<IOBluetoothUserNotification>>
Available on crate features objc2 and IOBluetoothUserNotification only.
pub unsafe fn registerForChannelOpenNotifications_selector( object: Option<&AnyObject>, selector: Option<Sel>, ) -> Option<Retained<IOBluetoothUserNotification>>
objc2 and IOBluetoothUserNotification only.Allows a client to register for RFCOMM channel open notifications for any RFCOMM channel.
The given selector will be called on the target object whenever any RFCOMM channel is opened. The selector should accept two arguments. The first is the user notification object. The second is the IOBluetoothRFCOMMChannel that was opened.
Parameter rfcommChannelRef: IOBluetoothRFCOMMChannelRef for which an IOBluetoothRFCOMMChannel * is desired.
Parameter object: Target object
Parameter selector: Selector to be called on the target object when a new RFCOMM channel is opened.
the format for the selector is:
-(void) selectorName:(IOBluetoothUserNotification *)inNotification channel:(IOBluetoothRFCOMMChannel *)newChannel
Returns: Returns an IOBluetoothUserNotification representing the outstanding RFCOMM channel notification. To unregister the notification, call -unregister on the resulting IOBluetoothUserNotification object. If an error is encountered creating the notification, nil is returned. The returned IOBluetoothUserNotification will be valid for as long as the notification is registered. It is not necessary to retain the result. Once -unregister is called on it, it will no longer be valid.
Safety
objectshould be of the correct type.objectmight not allowNone.selectormust be a valid selector.
Sourcepub unsafe fn registerForChannelOpenNotifications_selector_withChannelID_direction(
object: Option<&AnyObject>,
selector: Option<Sel>,
channel_id: BluetoothRFCOMMChannelID,
in_direction: IOBluetoothUserNotificationChannelDirection,
) -> Option<Retained<IOBluetoothUserNotification>>
Available on crate features objc2 and Bluetooth and IOBluetoothUserLib and IOBluetoothUserNotification only.
pub unsafe fn registerForChannelOpenNotifications_selector_withChannelID_direction( object: Option<&AnyObject>, selector: Option<Sel>, channel_id: BluetoothRFCOMMChannelID, in_direction: IOBluetoothUserNotificationChannelDirection, ) -> Option<Retained<IOBluetoothUserNotification>>
objc2 and Bluetooth and IOBluetoothUserLib and IOBluetoothUserNotification only.Allows a client to register for RFCOMM channel open notifications for certain types of RFCOMM channels.
The given selector will be called on the target object whenever an RFCOMM channel with the given attributes is opened. The selector should accept two arguments. The first is the user notification object. The second is the IOBluetoothRFCOMMChannel that was opened.
Parameter object: Target object
Parameter selector: Selector to be called on the target object when a new RFCOMM channel is opened.
the format for the selector is:
-(void) selectorName:(IOBluetoothUserNotification *)inNotification channel:(IOBluetoothRFCOMMChannel *)newChannel
Parameter channeLID: RFCOMM channel ID to match a new RFCOMM channel. If the channel ID doesn’t matter, 0 may be passed in.
Parameter inDirection: The desired direction of the RFCOMM channel - kIOBluetoothUserNotificationChannelDirectionAny
if the direction doesn’t matter.
Returns: Returns an IOBluetoothUserNotification representing the outstanding RFCOMM channel notification. To unregister the notification, call -unregister on the resulting IOBluetoothUserNotification object. If an error is encountered creating the notification, nil is returned. The returned IOBluetoothUserNotification will be valid for as long as the notification is registered. It is not necessary to retain the result. Once -unregister is called on it, it will no longer be valid.
Safety
objectshould be of the correct type.objectmight not allowNone.selectormust be a valid selector.
Sourcepub unsafe fn withRFCOMMChannelRef(
rfcomm_channel_ref: Option<&IOBluetoothRFCOMMChannelRef>,
) -> Option<Retained<Self>>
Available on crate features objc2 and IOBluetoothUserLib only.
pub unsafe fn withRFCOMMChannelRef( rfcomm_channel_ref: Option<&IOBluetoothRFCOMMChannelRef>, ) -> Option<Retained<Self>>
objc2 and IOBluetoothUserLib only.Method call to convert an IOBluetoothRFCOMMChannelRef into an IOBluetoothRFCOMMChannel *.
Parameter rfcommChannelRef: IOBluetoothRFCOMMChannelRef for which an IOBluetoothRFCOMMChannel * is desired.
Returns: Returns the IOBluetoothRFCOMMChannel * for the given IOBluetoothRFCOMMChannelRef.
Safety
rfcomm_channel_ref might not allow None.
Sourcepub unsafe fn withObjectID(
object_id: IOBluetoothObjectID,
) -> Option<Retained<Self>>
Available on crate features objc2 and IOBluetoothUserLib only.
pub unsafe fn withObjectID( object_id: IOBluetoothObjectID, ) -> Option<Retained<Self>>
objc2 and IOBluetoothUserLib only.Returns the IObluetoothRFCOMMChannel with the given IOBluetoothObjectID.
The IOBluetoothObjectID can be used as a global reference for a given IObluetoothRFCOMMChannel. It allows two separate applications to refer to the same IObluetoothRFCOMMChannel object.
Parameter objectID: IOBluetoothObjectID of the desired IObluetoothRFCOMMChannel.
Returns: Returns the IObluetoothRFCOMMChannel that matches the given IOBluetoothObjectID if one exists. If no matching RFCOMM channel exists, nil is returned.
Sourcepub unsafe fn getRFCOMMChannelRef(
&self,
) -> Option<Retained<IOBluetoothRFCOMMChannelRef>>
Available on crate features objc2 and IOBluetoothUserLib only.
pub unsafe fn getRFCOMMChannelRef( &self, ) -> Option<Retained<IOBluetoothRFCOMMChannelRef>>
objc2 and IOBluetoothUserLib only.Returns an IOBluetoothRFCOMMChannelRef representation of the target IOBluetoothRFCOMMChannel object.
Returns: Returns an IOBluetoothRFCOMMChannelRef representation of the target IOBluetoothRFCOMMChannel object.
Sourcepub unsafe fn closeChannel(&self) -> c_int
Available on crate feature objc2 only.
pub unsafe fn closeChannel(&self) -> c_int
objc2 only.Close the channel.
Returns: An error code value. 0 if successful.
Sourcepub unsafe fn isOpen(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isOpen(&self) -> bool
objc2 only.Returns the state of the channel.
note that “not open” means closed, opening and closing.
Returns: TRUE if the channel state is open, FALSE otherwise.
Sourcepub unsafe fn getMTU(&self) -> BluetoothRFCOMMMTU
Available on crate features objc2 and Bluetooth only.
pub unsafe fn getMTU(&self) -> BluetoothRFCOMMMTU
objc2 and Bluetooth only.Returns the channel maximum transfer unit.
Returns the length of the largest chunk of data that this channel can carry. If the caller wishes to use the write:length:sleep: api the length of the data can not be bigger than the channel MTU (maximum transfer unit).
Returns: Channel MTU size .
Sourcepub unsafe fn isTransmissionPaused(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isTransmissionPaused(&self) -> bool
objc2 only.Returns TRUE if flow control is off.
Returns true if the remote device flow control is stopping out transmission. This is useful because we do not buffer data, we stop the transmitting actor. With this method the transmitter can check if sending data is going to be successful or is going to block.
Returns: TRUE if the action of sending data will block the current thread, FALSE otherwise.
Sourcepub unsafe fn write_length_sleep(
&self,
data: *mut c_void,
length: u16,
sleep: bool,
) -> c_int
👎DeprecatedAvailable on crate feature objc2 only.
pub unsafe fn write_length_sleep( &self, data: *mut c_void, length: u16, sleep: bool, ) -> c_int
objc2 only.Sends a block of data in the channel syncronously.
WARNING This method is being deprecated in favor of -writeSync:… and -writeAsync:… Sends data through the channel. The number of bytes to be sent must not exceed the channel MTU. If the return value is an error condition none of the data was sent.
Parameter data: is a pointer to the data buffer to be sent.
Parameter length: the length of the buffer to be sent (in bytes).
Parameter sleep: is a boolean if set to TRUE the call will wait until it is possible to send data.
If set to FALSE and it is not possible to send data the method will return immediately with an
error.
Returns: An error code value. 0 if successful.
Safety
data must be a valid pointer.
Sourcepub unsafe fn writeAsync_length_refcon(
&self,
data: *mut c_void,
length: u16,
refcon: *mut c_void,
) -> c_int
Available on crate feature objc2 only.
pub unsafe fn writeAsync_length_refcon( &self, data: *mut c_void, length: u16, refcon: *mut c_void, ) -> c_int
objc2 only.Sends a block of data in the channel asynchronously.
The number of bytes to be sent must not exceed the channel MTU. If the return value is an error condition none of the data was sent. Once the data has been successfully passed to the hardware to be transmitted, the delegate method -rfcommChannelWriteComplete:refcon:status: will be called with the refcon that was passed to this method.
NOTE: This method is only available in Mac OS X 10.2.5 (Bluetooth v1.2) or later.
Parameter data: A pointer to the data buffer to be sent.
Parameter length: The length of the buffer to be sent (in bytes).
Parameter refcon: User supplied value that gets passed to the write callback.
Returns: Returns kIOReturnSuccess if the data was buffered successfully.
Safety
datamust be a valid pointer.refconmust be a valid pointer.
Sourcepub unsafe fn writeSync_length(&self, data: *mut c_void, length: u16) -> c_int
Available on crate feature objc2 only.
pub unsafe fn writeSync_length(&self, data: *mut c_void, length: u16) -> c_int
objc2 only.Sends a block of data in the channel synchronously.
Sends data through the channel. The number of bytes to be sent must not exceed the channel MTU. If the return value is an error condition none of the data was sent. This method will block until the data has been successfully sent to the hardware for transmission (or until an error occurs).
NOTE: This method is only available in Mac OS X 10.2.5 (Bluetooth v1.2) or later.
Parameter data: A pointer to the data buffer to be sent.
Parameter length: The length of the buffer to be sent (in bytes).
Returns: Returns kIOReturnSuccess if the data was written successfully.
Safety
data must be a valid pointer.
Sourcepub unsafe fn writeSimple_length_sleep_bytesSent(
&self,
data: *mut c_void,
length: u16,
sleep: bool,
num_bytes_sent: *mut u32,
) -> c_int
👎DeprecatedAvailable on crate feature objc2 only.
pub unsafe fn writeSimple_length_sleep_bytesSent( &self, data: *mut c_void, length: u16, sleep: bool, num_bytes_sent: *mut u32, ) -> c_int
objc2 only.Sends a block of data in the channel.
WARNING This method is being deprecated in favor of -writeSync:… and -writeAsync:… Sends data through the channel. The number of bytes to be sent is arbitrary. The caller does not have to worry about the MTU.
Parameter data: a pointer to the data buffer to be sent.
Parameter length: the length of the buffer to be sent (in bytes).
Parameter sleep: a boolean if set to TRUE the call will wait until it is possible to send all the data.
Parameter a: UInt32 pointer in which the caller received the nuber of bytes sent.
If set to FALSE and it is not possible to send part of the data the method will return immediately.
Returns: An error code value. 0 if successful.
Safety
datamust be a valid pointer.num_bytes_sentmust be a valid pointer.
Sourcepub unsafe fn setSerialParameters_dataBits_parity_stopBits(
&self,
speed: u32,
n_bits: u8,
parity: BluetoothRFCOMMParityType,
bit_stop: u8,
) -> c_int
Available on crate features objc2 and Bluetooth only.
pub unsafe fn setSerialParameters_dataBits_parity_stopBits( &self, speed: u32, n_bits: u8, parity: BluetoothRFCOMMParityType, bit_stop: u8, ) -> c_int
objc2 and Bluetooth only.Changes the parameters of the serial connection.
Parameter speed: the baudrate.
Parameter nBits: number of data bits.
Parameter parity: the type of parity can be NoParity, OddParity, EvenParity or MaxParity.
Parameter bitStop: number of stop bits.
Returns: An error code value. 0 if successful.
Sourcepub unsafe fn sendRemoteLineStatus(
&self,
line_status: BluetoothRFCOMMLineStatus,
) -> c_int
Available on crate features objc2 and Bluetooth only.
pub unsafe fn sendRemoteLineStatus( &self, line_status: BluetoothRFCOMMLineStatus, ) -> c_int
objc2 and Bluetooth only.Sends an error to the remote side.
Parameter lineStatus: the error type. The error code can be NoError, OverrunError, ParityError or FramingError.
Returns: An error code value. 0 if successful.
Sourcepub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>) -> c_int
Available on crate feature objc2 only.
pub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>) -> c_int
objc2 only.Allows an object to register itself as a client of the RFCOMM channel.
A channel delegate is the object the RFCOMM channel uses as target for data and events. The developer will implement only the the methods he/she is interested in. A list of the possible methods is at the end of this file in the definition of the informal protocol IOBluetoothRFCOMMChannelDelegate.
NOTE: This method is only available in Mac OS X 10.2.5 (Bluetooth v1.2) or later. NOTE: Before Mac OS X 10.6, the delegate was retained. On 10.6 and later, it is not.
Parameter delegate: The object that will play the role of channel delegate [NOTE the rfcomm channel will reatin the delegate].
Returns: Returns kIOReturnSuccess if the delegate is successfully registered.
Safety
delegateshould be of the correct type.delegatemight not allowNone.
Sourcepub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>
Available on crate feature objc2 only.
pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>
objc2 only.Returns the object delegate
Returns: the current delegate, or nil
Sourcepub unsafe fn getChannelID(&self) -> BluetoothRFCOMMChannelID
Available on crate features objc2 and Bluetooth only.
pub unsafe fn getChannelID(&self) -> BluetoothRFCOMMChannelID
objc2 and Bluetooth only.Returns the object rfcomm channel ID.
Returns: the RFCOMM channel number .
Sourcepub unsafe fn isIncoming(&self) -> bool
Available on crate feature objc2 only.
pub unsafe fn isIncoming(&self) -> bool
objc2 only.Returns the direction of the channel. An incoming channel is one that was opened by the remote device.
Returns: Returns TRUE if the channel was opened by the remote device, FALSE if the channel was opened by this object.
Sourcepub unsafe fn getDevice(&self) -> Option<Retained<IOBluetoothDevice>>
Available on crate features objc2 and IOBluetoothDevice only.
pub unsafe fn getDevice(&self) -> Option<Retained<IOBluetoothDevice>>
objc2 and IOBluetoothDevice only.Returns the Bluetooth Device that carries the rfcomm data.
Returns: the IOBluetoothDevice object .
Sourcepub unsafe fn getObjectID(&self) -> IOBluetoothObjectID
Available on crate features objc2 and IOBluetoothUserLib only.
pub unsafe fn getObjectID(&self) -> IOBluetoothObjectID
objc2 and IOBluetoothUserLib only.Returns the IOBluetoothObjectID of the given IOBluetoothRFCOMMChannel.
The IOBluetoothObjectID can be used as a global reference for a given IOBluetoothRFCOMMChannel. It allows two separate applications to refer to the same IOBluetoothRFCOMMChannel.
Returns: Returns the IOBluetoothObjectID of the given IOBluetoothRFCOMMChannel.
Sourcepub unsafe fn registerForChannelCloseNotification_selector(
&self,
observer: Option<&AnyObject>,
in_selector: Option<Sel>,
) -> Option<Retained<IOBluetoothUserNotification>>
Available on crate features objc2 and IOBluetoothUserNotification only.
pub unsafe fn registerForChannelCloseNotification_selector( &self, observer: Option<&AnyObject>, in_selector: Option<Sel>, ) -> Option<Retained<IOBluetoothUserNotification>>
objc2 and IOBluetoothUserNotification only.Allows a client to register for a channel close notification.
The given selector will be called on the target observer when the RFCOMM channel is closed. The selector should contain two arguments. The first is the user notification object. The second is the IOBluetoothRFCOMMChannel that was closed.
Parameter observer: Target observer object
Parameter inSelector: Selector to be sent to the observer when the RFCOMM channel is closed.
Returns: Returns an IOBluetoothUserNotification representing the outstanding RFCOMM channel close notification. To unregister the notification, call -unregister of the returned IOBluetoothUserNotification object. If an error is encountered creating the notification, nil is returned.
Safety
observershould be of the correct type.observermight not allowNone.in_selectormust be a valid selector.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl AsRef<AnyObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl AsRef<IOBluetoothObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl AsRef<IOBluetoothObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourcefn as_ref(&self) -> &IOBluetoothObject
fn as_ref(&self) -> &IOBluetoothObject
Sourceimpl AsRef<IOBluetoothRFCOMMChannel> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl AsRef<IOBluetoothRFCOMMChannel> for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl AsRef<NSObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl AsRef<NSObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl Borrow<AnyObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Borrow<AnyObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl Borrow<IOBluetoothObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Borrow<IOBluetoothObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourcefn borrow(&self) -> &IOBluetoothObject
fn borrow(&self) -> &IOBluetoothObject
Sourceimpl Borrow<NSObject> for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Borrow<NSObject> for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl ClassType for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl ClassType for IOBluetoothRFCOMMChannel
objc2 only.Sourceconst NAME: &'static str = "IOBluetoothRFCOMMChannel"
const NAME: &'static str = "IOBluetoothRFCOMMChannel"
Sourcetype Super = IOBluetoothObject
type Super = IOBluetoothObject
Sourcetype ThreadKind = <<IOBluetoothRFCOMMChannel as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<IOBluetoothRFCOMMChannel as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for IOBluetoothRFCOMMChannel
Available on crate features objc2 and objc2-foundation only.
impl CopyingHelper for IOBluetoothRFCOMMChannel
objc2 and objc2-foundation only.Sourcetype Result = IOBluetoothRFCOMMChannel
type Result = IOBluetoothRFCOMMChannel
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Debug for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl Deref for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Deref for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl Hash for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Hash for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl Message for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl Message for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl NSCopying for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl NSCopying for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl NSObjectProtocol for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl NSObjectProtocol for IOBluetoothRFCOMMChannel
objc2 only.Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSStreamDelegate for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl NSStreamDelegate for IOBluetoothRFCOMMChannel
objc2 only.fn stream_handleEvent(&self, a_stream: &NSStream, event_code: NSStreamEvent)
Sourceimpl PartialEq for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl PartialEq for IOBluetoothRFCOMMChannel
objc2 only.Sourceimpl RefEncode for IOBluetoothRFCOMMChannel
Available on crate feature objc2 only.
impl RefEncode for IOBluetoothRFCOMMChannel
objc2 only.Sourceconst ENCODING_REF: Encoding = <IOBluetoothObject as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <IOBluetoothObject as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for IOBluetoothRFCOMMChannel
objc2 only.impl Eq for IOBluetoothRFCOMMChannel
objc2 only.impl NSPortDelegate for IOBluetoothRFCOMMChannel
objc2 only.