pub unsafe trait NSObjectIOBluetoothHostControllerDelegate:
ClassType
+ Sized
+ Sealed {
// Provided methods
unsafe fn readRSSIForDeviceComplete_device_info_error(
&self,
controller: Option<&AnyObject>,
device: Option<&IOBluetoothDevice>,
info: *mut BluetoothHCIRSSIInfo,
error: c_int,
) { ... }
unsafe fn readLinkQualityForDeviceComplete_device_info_error(
&self,
controller: Option<&AnyObject>,
device: Option<&IOBluetoothDevice>,
info: *mut BluetoothHCILinkQualityInfo,
error: c_int,
) { ... }
}IOBluetoothHostController and objc2 only.Expand description
Category “IOBluetoothHostControllerDelegate” on NSObject.
This category on NSObject describes the delegate methods for the IOBluetoothHostController object. All
methods are optional, but it is highly recommended you implement them all. Do NOT invoke remote name
requests on found IOBluetoothDevice objects unless the controller object has been stopped. Doing so may
deadlock your process.
Provided Methods
Sourceunsafe fn readRSSIForDeviceComplete_device_info_error(
&self,
controller: Option<&AnyObject>,
device: Option<&IOBluetoothDevice>,
info: *mut BluetoothHCIRSSIInfo,
error: c_int,
)
Available on crate features Bluetooth and IOBluetoothDevice and IOBluetoothObject only.
unsafe fn readRSSIForDeviceComplete_device_info_error( &self, controller: Option<&AnyObject>, device: Option<&IOBluetoothDevice>, info: *mut BluetoothHCIRSSIInfo, error: c_int, )
Bluetooth and IOBluetoothDevice and IOBluetoothObject only.This delegate gets invoked when an RSSI command complete event occurs. This could occur because you invoked it by issuing an -readRSSIForDevice: command, or someone else did from another app on the same controller.
Parameter sender: Controller object that sent this delegate message.
Sourceunsafe fn readLinkQualityForDeviceComplete_device_info_error(
&self,
controller: Option<&AnyObject>,
device: Option<&IOBluetoothDevice>,
info: *mut BluetoothHCILinkQualityInfo,
error: c_int,
)
Available on crate features Bluetooth and IOBluetoothDevice and IOBluetoothObject only.
unsafe fn readLinkQualityForDeviceComplete_device_info_error( &self, controller: Option<&AnyObject>, device: Option<&IOBluetoothDevice>, info: *mut BluetoothHCILinkQualityInfo, error: c_int, )
Bluetooth and IOBluetoothDevice and IOBluetoothObject only.This delegate gets invoked when an read link quality command complete event occurs. This could occur because you invoked it by issuing an -readLinkQualityForDevice: command, or someone else did from another app on the same controller.
Parameter sender: Controller object that sent this delegate message.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.