NSObjectOBEXFileTransferServicesDelegate

Trait NSObjectOBEXFileTransferServicesDelegate 

pub unsafe trait NSObjectOBEXFileTransferServicesDelegate:
    ClassType
    + Sized
    + Sealed {
    // Provided methods
    unsafe fn fileTransferServicesConnectionComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
    unsafe fn fileTransferServicesDisconnectionComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
    unsafe fn fileTransferServicesAbortComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
    unsafe fn fileTransferServicesRemoveItemComplete_error_removedItem(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
        in_item_name: Option<&NSString>,
    ) { ... }
    unsafe fn fileTransferServicesCreateFolderComplete_error_folder(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
        in_folder_name: Option<&NSString>,
    ) { ... }
    unsafe fn fileTransferServicesPathChangeComplete_error_finalPath(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
        in_path: Option<&NSString>,
    ) { ... }
    unsafe fn fileTransferServicesRetrieveFolderListingComplete_error_listing(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
        in_listing: Option<&NSArray>,
    ) { ... }
    unsafe fn fileTransferServicesFilePreparationComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
    unsafe fn fileTransferServicesSendFileProgress_transferProgress(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_progress_description: Option<&NSDictionary>,
    ) { ... }
    unsafe fn fileTransferServicesSendFileComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
    unsafe fn fileTransferServicesCopyRemoteFileProgress_transferProgress(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_progress_description: Option<&NSDictionary>,
    ) { ... }
    unsafe fn fileTransferServicesCopyRemoteFileComplete_error(
        &self,
        in_services: Option<&OBEXFileTransferServices>,
        in_error: OBEXError,
    ) { ... }
}
Available on crate features OBEXFileTransferServices and objc2 only.
Category “OBEXFileTransferServicesDelegate” on NSObject.

Provided Methods

unsafe fn fileTransferServicesConnectionComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method that corresponds to the connect method

inError will either be kOBEXSuccess or it will be an error returned by the OBEX Session

unsafe fn fileTransferServicesDisconnectionComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method that corresponds to the disconnect method

inError will be kOBEXSuccess on success. This method will also be called if the connection is lost to the server. Possible error codes include kOBEXSessionTransportDiedError, kOBEXSessionNoTransportError, and kOBEXSessionNotConnectedError.

unsafe fn fileTransferServicesAbortComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method that corresponds to the abort method

Possible inError values are kOBEXSuccess and kOBEXTimeoutError

unsafe fn fileTransferServicesRemoveItemComplete_error_removedItem( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, in_item_name: Option<&NSString>, )

Available on crate features OBEX and objc2-foundation only.

The delegate method that corresponds to the removeItemNamed: method.

Parameter inItemName: The name of the remote item that was removed

unsafe fn fileTransferServicesCreateFolderComplete_error_folder( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, in_folder_name: Option<&NSString>, )

Available on crate features OBEX and objc2-foundation only.

The delegate method that corresponds to the createFolderNamed: method.

Parameter inFolderName: The name of the newly created folder

unsafe fn fileTransferServicesPathChangeComplete_error_finalPath( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, in_path: Option<&NSString>, )

Available on crate features OBEX and objc2-foundation only.

The delegate method that corresponds to the changeCurrentFolderToRoot:, changeCurrentFolderBackward:, and changeCurrentFolderForward: methods

Parameter inPath: The current remote path

unsafe fn fileTransferServicesRetrieveFolderListingComplete_error_listing( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, in_listing: Option<&NSArray>, )

Available on crate features OBEX and objc2-foundation only.

The delegate method that corresponds to the retrieveFolderListing method

Parameter inListing: An array of NSDictionary’s that detail each file at the current path. The keys to this dictionary are defined in the OBEXFileTransferServicesDelegate category.

unsafe fn fileTransferServicesFilePreparationComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method for receiving information on the preparation of each file to send

This method will be called before the transfer operation.

unsafe fn fileTransferServicesSendFileProgress_transferProgress( &self, in_services: Option<&OBEXFileTransferServices>, in_progress_description: Option<&NSDictionary>, )

Available on crate feature objc2-foundation only.

The delegate method for receiving information on the sendFile: transfer

This method will be called during the transfer operation.

Parameter inProgressDescription: A dictionary containing information on the state of the transfer. The keys to this dictionary are defined in the OBEXFileTransferServicesDelegate category.

unsafe fn fileTransferServicesSendFileComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method that corresponds to the sendFile: method.

This method will be called when the transfer operation has finished.

unsafe fn fileTransferServicesCopyRemoteFileProgress_transferProgress( &self, in_services: Option<&OBEXFileTransferServices>, in_progress_description: Option<&NSDictionary>, )

Available on crate feature objc2-foundation only.

The delegate method for receiving information on the GET transfer

This method will be called during the transfer operation

Parameter inProgressDescription: A dictionary containing information on the state of the transfer. The keys to this dictionary are defined in the OBEXFileTransferServicesDelegate category.

unsafe fn fileTransferServicesCopyRemoteFileComplete_error( &self, in_services: Option<&OBEXFileTransferServices>, in_error: OBEXError, )

Available on crate feature OBEX only.

The delegate method that corresponds to the getFileNamed:toLocalPathAndName: method

This method will be called when the transfer operation has finished

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl NSObjectOBEXFileTransferServicesDelegate for NSObject

Implementors