IOBluetoothGetUniqueFileNameAndPath

Function IOBluetoothGetUniqueFileNameAndPath 

pub unsafe extern "C-unwind" fn IOBluetoothGetUniqueFileNameAndPath(
    in_name: Option<&NSString>,
    in_path: Option<&NSString>,
) -> Option<Retained<NSString>>
Available on crate features IOBluetoothUtilities and objc2 and objc2-foundation only.
Parameter inName: Name of file that needs unique name in the specified path.

Parameter inPath: Path you are trying to put file into.

Returns: String with a unique name appended on it for the provided path.

When passed a VALID filename and a VALID path, this routine will return you a the path with the name appended onto it. If it already exist, it will insert a #1, #2, etc. Example: If you pass &#64 “TestFile.txt” and &#64 “~/Documents”, you will get &#64 “~Documents/TestFile.txt”. If one already exists, you will be returned: &#64 “~Documents/TestFile #1.txt”.