pub unsafe extern "C-unwind" fn IOBluetoothOBEXSessionCreateWithIOBluetoothSDPServiceRecordRef(
in_sdp_service_ref: &IOBluetoothSDPServiceRecordRef,
out_session_ref: *mut OBEXSessionRef,
) -> OBEXError👎Deprecated
Available on crate features
IOBluetoothUserLib and OBEX and OBEXBluetooth only.Expand description
Create an OBEX session with a service ref, usually obtained from the device browser.
Parameter inSDPServiceRecordRef: A valid service reference.
Parameter outSessionRef: A valid ptr to an IOBluetoothOBEXSessionRef; will contain the newly created session if
return value is kOBEXSuccess.
Returns: An error code value. 0 if successful.
You will use a session reference to do all OBEX interaction to a specific device. This method DOES NOT create a connection to the device of any kind.
** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.