pub unsafe extern "C-unwind" fn OBEXAddAuthorizationResponseHeader(
in_header_data: *const c_void,
in_header_data_length: u32,
dict_ref: Option<&CFMutableDictionary>,
) -> OBEXErrorAvailable on crate features
OBEX and objc2-core-foundation only.Expand description
Add an authorization Response header to a dictionary of OBEXheaders.
Parameter inHeaderData: bytes you want to put in the authorization Response header.
Parameter inHeaderDataLength: length of the bytes you want to put in authorization Response header.
Parameter dictRef: dictionary you have allocated to hold the headers. Make sure it’s mutable.
Returns: Error code, kOBEXSuccess (0) if success.
Authorization Response header - OBEX Spec, 2.2.14: Authorization Response.