pub unsafe extern "C-unwind" fn OBEXSessionGetMaxPacketLength(
in_session_ref: OBEXSessionRef,
out_length: *mut OBEXMaxPacketLength,
) -> OBEXError👎Deprecated
Available on crate feature
OBEX only.Expand description
Gets current max packet length.
Parameter inSessionRef: A valid session reference.
Parameter outLength: Max packet length.
Returns: An error code value. 0 if successful.
This value could change before and after a connect command has been sent or a connect command response has been received, since the recipient could negotiate a lower max packet size.
** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.