pub unsafe extern "C-unwind" fn OBEXSessionHasOpenOBEXConnection(
in_session_ref: OBEXSessionRef,
out_is_connected: *mut u8,
) -> OBEXError👎Deprecated
Available on crate feature
OBEX only.Expand description
Allows you to test the session for an open OBEX connection for a particular session.
Parameter inSessionRef: A valid session reference.
Parameter outIsConnected: A valid ptr to an OBEXSessionRef; will contain the newly created session if return
value is kOBEXSuccess.
Returns: An error code value. 0 if successful.
This method will return true only if (a) you are transport-connected to another OBEX target and (b) an OBEX Connect command has been issued and received successfully.
** DEPRECATED IN BLUETOOTH 2.2 (Mac OS X 10.6) ** You should transition your code to Objective-C equivalents. ** This API may be removed any time in the future.