IOBluetoothHandsFree

Struct IOBluetoothHandsFree 

#[repr(C)]
pub struct IOBluetoothHandsFree { /* private fields */ }
Available on crate features IOBluetoothHandsFree and objc2 only.
Hands free profile class.

Superclass of IOBluetoothHandsFreeDevice and IOBluetoothHandsFreeAudioGateway classes. Contains the common code used to support the bluetoooth hands free profile.

IOBluetoothHandsFreeDevice

IOBluetoothHandsFreeAudioGateway

See also Apple’s documentation

Implementations

Source

impl IOBluetoothHandsFree

pub unsafe fn supportedFeatures(&self) -> u32

Return supported features

Returns the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”

Returns: The supported features bitmap

Set the supported features

Sets the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”

Parameter featuresBitmap: The features bitmap

pub unsafe fn setSupportedFeatures(&self, supported_features: u32)

Setter for supportedFeatures.

pub unsafe fn inputVolume(&self) -> c_float

Return the input volume

Returns the input volume between 0 and 1. 0 is the same as mute.

Returns: The input volume

Set the input volume

Sets the input volume between 0 and 1. 0 is the same as mute.

Parameter newVolume: The new input volume

pub unsafe fn setInputVolume(&self, input_volume: c_float)

Setter for inputVolume.

pub unsafe fn isInputMuted(&self) -> bool

Return the input mute state.

Returns the inputs mute state.

Returns: YES if muted; otherwise NO.

Set the input mute state.

Sets the inputs mute state.

Parameter muted: YES if muted; otherwise NO.

pub unsafe fn setInputMuted(&self, input_muted: bool)

Setter for isInputMuted.

pub unsafe fn outputVolume(&self) -> c_float

Return the output volume

Returns the output volume between 0 and 1. 0 is the same as mute.

Returns: The output volume

Set the output volume

Sets the output volume between 0 and 1. 0 is the same as mute.

Parameter newVolume: The new output volume

pub unsafe fn setOutputVolume(&self, output_volume: c_float)

Setter for outputVolume.

pub unsafe fn isOutputMuted(&self) -> bool

Return the output mute state.

Returns the outputs mute state.

Returns: YES if muted; otherwise NO.

Set the output mute state.

Sets the outputs mute state.

Parameter muted: YES if muted; otherwise NO.

pub unsafe fn setOutputMuted(&self, output_muted: bool)

Setter for isOutputMuted.

pub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>

Available on crate features IOBluetoothDevice and IOBluetoothObject only.

Return the IOBluetoothDevice.

Returns the IOBluetoothDevice to connect with.

Returns: The IOBluetoothDevice object

pub unsafe fn deviceSupportedFeatures(&self) -> u32

Return the device’s supported features.

Returns the device’s supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”

Returns: The device features bitmap

pub unsafe fn deviceSupportedSMSServices(&self) -> u32

Return the device’s supported SMS services.

Returns the device’s supported SMS services bitmap. The values are described in “IOBluetoothHandsFreeSMSSupport.”

Returns: The SMS services supported

pub unsafe fn deviceCallHoldModes(&self) -> u32

Return the device’s supported call hold modes.

Returns the device’s supported call hold modes bitmap. The values are described in “IOBluetoothHandsFreeCallHoldModes.”

Returns: The SMS services supported

pub unsafe fn SMSMode(&self) -> IOBluetoothSMSMode

Return the device’s SMS mode.

Returns the device’s SMS mode. The values are described in “IOBluetoothSMSMode.”

Returns: The SMS mode

pub unsafe fn isSMSEnabled(&self) -> bool

Return YES if the device has SMS enabled.

Returns YES if the device has SMS enabled (by responding to a CMGF command). NO if the device has not set an SMS mode or doesn’t support SMS.

Returns: YES if the device has SMSEnabled; otherwise, NO.

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>>

Return the delegate

Returns the hands free object’s delegate.

Returns: The delegate for the hands free object or nil if it doesn’t have a delegate.

Sets the hands free object’s delegate to a given object or removes an existing delegate.

A IOBluetoothHandsFree delegate can optionally respond to any of the delegate methods in IOBluetoothHandsFreeDelegate and any subclasses delegates.

Parameter newDelegate: The delegate for the hands free object. Pass nil to remove an existing delegate.

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>, )

Setter for delegate.

pub unsafe fn indicator(&self, indicator_name: Option<&NSString>) -> c_int

Available on crate feature objc2-foundation only.

Return an indicator’s value

Returns an indicator’s value.

Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.

pub unsafe fn setIndicator_value( &self, indicator_name: Option<&NSString>, indicator_value: c_int, )

Available on crate feature objc2-foundation only.

Set an indicator’s value

Sets an indicator’s value.

Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.

Parameter indicatorValue: Will set the indicator value as long as it is within the min and max values allowed.

pub unsafe fn initWithDevice_delegate( this: Allocated<Self>, device: Option<&IOBluetoothDevice>, in_delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>, ) -> Option<Retained<Self>>

Available on crate features IOBluetoothDevice and IOBluetoothObject only.

Create a new IOBluetoothHandsFree object

This method should be called on a subclass (IOBluetoothHandsFreeDevice or IOBluetoothHandsFreeAudioGateway) to get full functionality.

Parameter device: An IOBluetoothDevice

Parameter inDelegate: An object to act as delegate that implements the IOBluetoothHandsFreeDelegate protocol.

Returns: A newly created IOBluetoothHandsFreeAudioGateway object on success, nil on failure

pub unsafe fn connect(&self)

Connect to the device

Connects to the device and sets up a service level connection (RFCOMM channel). Delegate methods will be called once the connection is complete or a failure occurs.

pub unsafe fn disconnect(&self)

Disconnect from the device

Disconnects from the device, closes the SCO and service level connection if they are connected. Delegate methods will be called once the disconnection is complete.

pub unsafe fn isConnected(&self) -> bool

Determine if there is a serivice level connection to the device

Determines if there is a serivice level connection to the device.

Returns: YES if there is a serivice level connection to the device; otherwise, NO.

pub unsafe fn connectSCO(&self)

Open a SCO connection with the device

Opens a SCO connection with the device. The device must already have a service level connection or this will return immediately. Delegate methods will be called once the connection is complete of a failure occurs.

pub unsafe fn disconnectSCO(&self)

Disconnect the SCO connection with the device

Disconnects the SCO connection with the device (if one exists). Delegate methods will be called once the disconnection is complete.

pub unsafe fn isSCOConnected(&self) -> bool

Determine if there is a SCO connection to the device

Determines if there is a SCO connection to the device.

Returns: YES if there is a SCO connection to the device; otherwise, NO.

Source

impl IOBluetoothHandsFree

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}