#[repr(C)]pub struct IOBluetoothHandsFreeDevice { /* private fields */ }IOBluetoothHandsFreeDevice and objc2 and IOBluetoothHandsFree only.Expand description
APIs for managing a hands free device
(c) 2010 by Apple Inc. All rights reserved.
See also Apple’s documentation
Implementations
Sourceimpl IOBluetoothHandsFreeDevice
impl IOBluetoothHandsFreeDevice
Sourcepub unsafe fn initWithDevice_delegate(
this: Allocated<Self>,
device: Option<&IOBluetoothDevice>,
delegate: Option<&AnyObject>,
) -> Option<Retained<Self>>
Available on crate features IOBluetoothDevice and IOBluetoothObject only.
pub unsafe fn initWithDevice_delegate( this: Allocated<Self>, device: Option<&IOBluetoothDevice>, delegate: Option<&AnyObject>, ) -> Option<Retained<Self>>
IOBluetoothDevice and IOBluetoothObject only.Create a new IOBluetoothHandsFreeDevice to act as a hands free device
This will register a listener for incoming connections.
Parameter device: An IOBluetoothDevice
Parameter inDelegate: An object to act as delegate
Returns: A newly created IOBluetoothHandsFreeDevice object on success, nil on failure
Sourcepub unsafe fn dialNumber(&self, a_number: Option<&NSString>)
Available on crate feature objc2-foundation only.
pub unsafe fn dialNumber(&self, a_number: Option<&NSString>)
objc2-foundation only.Dial a number
Calls aNumber
Parameter aNumber: The number to call - the gateway determines acceptable formats.
Sourcepub unsafe fn memoryDial(&self, memory_location: c_int)
pub unsafe fn memoryDial(&self, memory_location: c_int)
Dial a number from memory
Calls a number from a memory (or speed dial) location.
Parameter memoryLocation: The location in memory
Sourcepub unsafe fn redial(&self)
pub unsafe fn redial(&self)
Redial a number
Redials the previous number stored by the hands free gateway.
Sourcepub unsafe fn endCall(&self)
pub unsafe fn endCall(&self)
Hang up a call or reject an incoming call
Hangs up the current call, or rejects an incoming call.
Sourcepub unsafe fn acceptCall(&self)
pub unsafe fn acceptCall(&self)
Accept an incoming call
Accepts an incoming call.
Sourcepub unsafe fn acceptCallOnPhone(&self)
pub unsafe fn acceptCallOnPhone(&self)
Accept an incoming call on the phone
Accepts an incoming call and then quickly transfer audio to the phone.
Sourcepub unsafe fn sendDTMF(&self, character: Option<&NSString>)
Available on crate feature objc2-foundation only.
pub unsafe fn sendDTMF(&self, character: Option<&NSString>)
objc2-foundation only.Send a key press
Sends a DTMF tone.
Parameter character: A single character in the set 0-9, #,*,A-D
Sourcepub unsafe fn subscriberNumber(&self)
pub unsafe fn subscriberNumber(&self)
Get the subscriber number(s)
Gets the subscriber number(s) stored on the gateway. Each subscriber number is returned on the delegate method handsFree:subscriberNumber. There is no guarantee that the gateway will have a subscriber number.
Sourcepub unsafe fn currentCallList(&self)
pub unsafe fn currentCallList(&self)
Get the current call list
Gets the current call list (active, held, and setup in process). Each call is returned on the delegate method handsFree:currentCall.
Sourcepub unsafe fn releaseHeldCalls(&self)
pub unsafe fn releaseHeldCalls(&self)
Release all held calls
Releases all held calls or sets User Determined User Busy for a waiting call.
Sourcepub unsafe fn releaseActiveCalls(&self)
pub unsafe fn releaseActiveCalls(&self)
Release all active calls
Releases all active calls (if any exist) and accepts the other (held or waiting) call.
Sourcepub unsafe fn releaseCall(&self, index: c_int)
pub unsafe fn releaseCall(&self, index: c_int)
Release an active call.
Releases the active call with index.
Parameter index: Index of the call to release
Sourcepub unsafe fn holdCall(&self)
pub unsafe fn holdCall(&self)
Place all active calls on hold
Places all active calls (if any exist) on hold and accepts the other (held or waiting) call.
Sourcepub unsafe fn placeAllOthersOnHold(&self, index: c_int)
pub unsafe fn placeAllOthersOnHold(&self, index: c_int)
Place all other calls on hold.
Places all calls on hold except call with index.
Parameter index: Index of the call to not place on hold
Sourcepub unsafe fn addHeldCall(&self)
pub unsafe fn addHeldCall(&self)
Add a held call to the current conversation
Adds a held call to the current conversation.
Sourcepub unsafe fn callTransfer(&self)
pub unsafe fn callTransfer(&self)
Release all active calls
Releases all active calls (if any exist) and accepts the other (held or waiting) call.
Sourcepub unsafe fn transferAudioToComputer(&self)
pub unsafe fn transferAudioToComputer(&self)
Transfer audio source to the computer.
Transfers audio to the computer.
Sourcepub unsafe fn transferAudioToPhone(&self)
pub unsafe fn transferAudioToPhone(&self)
Transfer audio source to the phone.
Transfers audio to the phone.
Sourcepub unsafe fn sendSMS_message(
&self,
a_number: Option<&NSString>,
a_message: Option<&NSString>,
)
Available on crate feature objc2-foundation only.
pub unsafe fn sendSMS_message( &self, a_number: Option<&NSString>, a_message: Option<&NSString>, )
objc2-foundation only.Send an SMS to a number.
Sends an SMS to aNumber with content aMessage. Currently this does not handle long SMS (>160 characters) or unicode messages.
Sourcepub unsafe fn sendATCommand(&self, at_command: Option<&NSString>)
Available on crate feature objc2-foundation only.
pub unsafe fn sendATCommand(&self, at_command: Option<&NSString>)
objc2-foundation only.Send an AT command to the hands free gateway.
Sends an AT command to the hands free gateway with a timeout of 10 seconds and handled by the built-in response handling. See sendAtCommand:timeout:selector:target for more details.
Parameter atCommand: AT command to send
Sourcepub unsafe fn sendATCommand_timeout_selector_target(
&self,
at_command: Option<&NSString>,
timeout: c_float,
selector: Option<Sel>,
target: Option<&AnyObject>,
)
Available on crate feature objc2-foundation only.
pub unsafe fn sendATCommand_timeout_selector_target( &self, at_command: Option<&NSString>, timeout: c_float, selector: Option<Sel>, target: Option<&AnyObject>, )
objc2-foundation only.Send an AT command to the hands free gateway.
Sends an AT command to the hands free gateway with timeout. On command complete (OK, ERROR, TIMEOUT response or after timeout seconds) will perform selector on target.
Parameter atCommand: AT command to send
Methods from Deref<Target = IOBluetoothHandsFree>
Sourcepub unsafe fn supportedFeatures(&self) -> u32
pub unsafe fn supportedFeatures(&self) -> u32
Return supported features
Returns the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Returns: The supported features bitmap
Set the supported features
Sets the supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Parameter featuresBitmap: The features bitmap
Sourcepub unsafe fn setSupportedFeatures(&self, supported_features: u32)
pub unsafe fn setSupportedFeatures(&self, supported_features: u32)
Setter for supportedFeatures.
Sourcepub unsafe fn inputVolume(&self) -> c_float
pub unsafe fn inputVolume(&self) -> c_float
Return the input volume
Returns the input volume between 0 and 1. 0 is the same as mute.
Returns: The input volume
Set the input volume
Sets the input volume between 0 and 1. 0 is the same as mute.
Parameter newVolume: The new input volume
Sourcepub unsafe fn setInputVolume(&self, input_volume: c_float)
pub unsafe fn setInputVolume(&self, input_volume: c_float)
Setter for inputVolume.
Sourcepub unsafe fn isInputMuted(&self) -> bool
pub unsafe fn isInputMuted(&self) -> bool
Return the input mute state.
Returns the inputs mute state.
Returns: YES if muted; otherwise NO.
Set the input mute state.
Sets the inputs mute state.
Parameter muted: YES if muted; otherwise NO.
Sourcepub unsafe fn setInputMuted(&self, input_muted: bool)
pub unsafe fn setInputMuted(&self, input_muted: bool)
Setter for isInputMuted.
Sourcepub unsafe fn outputVolume(&self) -> c_float
pub unsafe fn outputVolume(&self) -> c_float
Return the output volume
Returns the output volume between 0 and 1. 0 is the same as mute.
Returns: The output volume
Set the output volume
Sets the output volume between 0 and 1. 0 is the same as mute.
Parameter newVolume: The new output volume
Sourcepub unsafe fn setOutputVolume(&self, output_volume: c_float)
pub unsafe fn setOutputVolume(&self, output_volume: c_float)
Setter for outputVolume.
Sourcepub unsafe fn isOutputMuted(&self) -> bool
pub unsafe fn isOutputMuted(&self) -> bool
Return the output mute state.
Returns the outputs mute state.
Returns: YES if muted; otherwise NO.
Set the output mute state.
Sets the outputs mute state.
Parameter muted: YES if muted; otherwise NO.
Sourcepub unsafe fn setOutputMuted(&self, output_muted: bool)
pub unsafe fn setOutputMuted(&self, output_muted: bool)
Setter for isOutputMuted.
Sourcepub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>
Available on crate features IOBluetoothDevice and IOBluetoothObject only.
pub unsafe fn device(&self) -> Option<Retained<IOBluetoothDevice>>
IOBluetoothDevice and IOBluetoothObject only.Return the IOBluetoothDevice.
Returns the IOBluetoothDevice to connect with.
Returns: The IOBluetoothDevice object
Sourcepub unsafe fn deviceSupportedFeatures(&self) -> u32
pub unsafe fn deviceSupportedFeatures(&self) -> u32
Return the device’s supported features.
Returns the device’s supported features bitmap. The values are described in “IOBluetoothHandsFreeDeviceFeatures and IOBluetoothHandsFreeAudioGatewayFeatures.”
Returns: The device features bitmap
Sourcepub unsafe fn deviceSupportedSMSServices(&self) -> u32
pub unsafe fn deviceSupportedSMSServices(&self) -> u32
Return the device’s supported SMS services.
Returns the device’s supported SMS services bitmap. The values are described in “IOBluetoothHandsFreeSMSSupport.”
Returns: The SMS services supported
Sourcepub unsafe fn deviceCallHoldModes(&self) -> u32
pub unsafe fn deviceCallHoldModes(&self) -> u32
Return the device’s supported call hold modes.
Returns the device’s supported call hold modes bitmap. The values are described in “IOBluetoothHandsFreeCallHoldModes.”
Returns: The SMS services supported
Sourcepub unsafe fn SMSMode(&self) -> IOBluetoothSMSMode
pub unsafe fn SMSMode(&self) -> IOBluetoothSMSMode
Return the device’s SMS mode.
Returns the device’s SMS mode. The values are described in “IOBluetoothSMSMode.”
Returns: The SMS mode
Sourcepub unsafe fn isSMSEnabled(&self) -> bool
pub unsafe fn isSMSEnabled(&self) -> bool
Return YES if the device has SMS enabled.
Returns YES if the device has SMS enabled (by responding to a CMGF command). NO if the device has not set an SMS mode or doesn’t support SMS.
Returns: YES if the device has SMSEnabled; otherwise, NO.
Sourcepub unsafe fn delegate(
&self,
) -> Option<Retained<ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>>
pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>>
Return the delegate
Returns the hands free object’s delegate.
Returns: The delegate for the hands free object or nil if it doesn’t have a delegate.
Sets the hands free object’s delegate to a given object or removes an existing delegate.
A IOBluetoothHandsFree delegate can optionally respond to any of the delegate methods in IOBluetoothHandsFreeDelegate and any subclasses delegates.
Parameter newDelegate: The delegate for the hands free object. Pass nil to remove an existing delegate.
Sourcepub unsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>,
)
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn IOBluetoothHandsFreeDelegate>>, )
Setter for delegate.
Sourcepub unsafe fn indicator(&self, indicator_name: Option<&NSString>) -> c_int
Available on crate feature objc2-foundation only.
pub unsafe fn indicator(&self, indicator_name: Option<&NSString>) -> c_int
objc2-foundation only.Return an indicator’s value
Returns an indicator’s value.
Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.
Sourcepub unsafe fn setIndicator_value(
&self,
indicator_name: Option<&NSString>,
indicator_value: c_int,
)
Available on crate feature objc2-foundation only.
pub unsafe fn setIndicator_value( &self, indicator_name: Option<&NSString>, indicator_value: c_int, )
objc2-foundation only.Set an indicator’s value
Sets an indicator’s value.
Parameter indicatorName: See “Hands free indicator constants,“ for standard indicator names.
Parameter indicatorValue: Will set the indicator value as long as it is within the min and max values allowed.
Sourcepub unsafe fn connect(&self)
pub unsafe fn connect(&self)
Connect to the device
Connects to the device and sets up a service level connection (RFCOMM channel). Delegate methods will be called once the connection is complete or a failure occurs.
Sourcepub unsafe fn disconnect(&self)
pub unsafe fn disconnect(&self)
Disconnect from the device
Disconnects from the device, closes the SCO and service level connection if they are connected. Delegate methods will be called once the disconnection is complete.
Sourcepub unsafe fn isConnected(&self) -> bool
pub unsafe fn isConnected(&self) -> bool
Determine if there is a serivice level connection to the device
Determines if there is a serivice level connection to the device.
Returns: YES if there is a serivice level connection to the device; otherwise, NO.
Sourcepub unsafe fn connectSCO(&self)
pub unsafe fn connectSCO(&self)
Open a SCO connection with the device
Opens a SCO connection with the device. The device must already have a service level connection or this will return immediately. Delegate methods will be called once the connection is complete of a failure occurs.
Sourcepub unsafe fn disconnectSCO(&self)
pub unsafe fn disconnectSCO(&self)
Disconnect the SCO connection with the device
Disconnects the SCO connection with the device (if one exists). Delegate methods will be called once the disconnection is complete.
Sourcepub unsafe fn isSCOConnected(&self) -> bool
pub unsafe fn isSCOConnected(&self) -> bool
Determine if there is a SCO connection to the device
Determines if there is a SCO connection to the device.
Returns: YES if there is a SCO connection to the device; otherwise, NO.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for IOBluetoothHandsFreeDevice
impl AsRef<AnyObject> for IOBluetoothHandsFreeDevice
Sourceimpl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
impl AsRef<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
Sourcefn as_ref(&self) -> &IOBluetoothHandsFree
fn as_ref(&self) -> &IOBluetoothHandsFree
Sourceimpl AsRef<NSObject> for IOBluetoothHandsFreeDevice
impl AsRef<NSObject> for IOBluetoothHandsFreeDevice
Sourceimpl Borrow<AnyObject> for IOBluetoothHandsFreeDevice
impl Borrow<AnyObject> for IOBluetoothHandsFreeDevice
Sourceimpl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
impl Borrow<IOBluetoothHandsFree> for IOBluetoothHandsFreeDevice
Sourcefn borrow(&self) -> &IOBluetoothHandsFree
fn borrow(&self) -> &IOBluetoothHandsFree
Sourceimpl Borrow<NSObject> for IOBluetoothHandsFreeDevice
impl Borrow<NSObject> for IOBluetoothHandsFreeDevice
Sourceimpl ClassType for IOBluetoothHandsFreeDevice
impl ClassType for IOBluetoothHandsFreeDevice
Sourceconst NAME: &'static str = "IOBluetoothHandsFreeDevice"
const NAME: &'static str = "IOBluetoothHandsFreeDevice"
Sourcetype Super = IOBluetoothHandsFree
type Super = IOBluetoothHandsFree
Sourcetype ThreadKind = <<IOBluetoothHandsFreeDevice as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<IOBluetoothHandsFreeDevice as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for IOBluetoothHandsFreeDevice
impl Debug for IOBluetoothHandsFreeDevice
Sourceimpl Deref for IOBluetoothHandsFreeDevice
impl Deref for IOBluetoothHandsFreeDevice
Sourceimpl Hash for IOBluetoothHandsFreeDevice
impl Hash for IOBluetoothHandsFreeDevice
Sourceimpl Message for IOBluetoothHandsFreeDevice
impl Message for IOBluetoothHandsFreeDevice
Sourceimpl NSObjectProtocol for IOBluetoothHandsFreeDevice
impl NSObjectProtocol for IOBluetoothHandsFreeDevice
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref