#[repr(C)]pub struct IOBluetoothHostController { /* private fields */ }IOBluetoothHostController and objc2 only.Expand description
This class is a representation of a Bluetooth Host Controller Interface that is present on the local computer (either plugged in externally or available internally).
This object can be used to ask a Bluetooth HCI for certain pieces of information, and be used to make it perform certain functions.
See also Apple’s documentation
Implementations
Sourceimpl IOBluetoothHostController
impl IOBluetoothHostController
pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>
Sourcepub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>)
pub unsafe fn setDelegate(&self, delegate: Option<&AnyObject>)
This is a weak property.
Setter for delegate.
Sourcepub unsafe fn defaultController() -> Option<Retained<Self>>
pub unsafe fn defaultController() -> Option<Retained<Self>>
Gets the default HCI controller object.
Returns: A (autoreleased) pointer to the created IOBluetoothHostController object.
Sourcepub unsafe fn powerState(&self) -> BluetoothHCIPowerState
Available on crate feature Bluetooth only.
pub unsafe fn powerState(&self) -> BluetoothHCIPowerState
Bluetooth only.Gets the controller power state
Returns: The current controller’s power state. This will be 1 for on, or 0 for off. Only Apple Bluetooth adapters support power off
Sourcepub unsafe fn classOfDevice(&self) -> BluetoothClassOfDevice
Available on crate feature Bluetooth only.
pub unsafe fn classOfDevice(&self) -> BluetoothClassOfDevice
Bluetooth only.Gets the current class of device value.
Returns: Returns the current class of device value.
Sourcepub unsafe fn setClassOfDevice_forTimeInterval(
&self,
class_of_device: BluetoothClassOfDevice,
seconds: NSTimeInterval,
) -> c_int
Available on crate features Bluetooth and objc2-foundation only.
pub unsafe fn setClassOfDevice_forTimeInterval( &self, class_of_device: BluetoothClassOfDevice, seconds: NSTimeInterval, ) -> c_int
Bluetooth and objc2-foundation only.Sets the current class of device value, for the specified amount of time. Note that the time interval must be set and valid. The range of acceptable values is 30-120 seconds. Anything above or below will be rounded up, or down, as appropriate.
Returns: Returns the whether setting the class of device value was successful. 0 if success, error code otherwise.
Sourcepub unsafe fn addressAsString(&self) -> Option<Retained<NSString>>
Available on crate feature objc2-foundation only.
pub unsafe fn addressAsString(&self) -> Option<Retained<NSString>>
objc2-foundation only.Convience routine to get the HCI controller’s Bluetooth address as an NSString object.
Returns: Returns NSString *. nil if the address could not be retrieved.
Sourcepub unsafe fn nameAsString(&self) -> Option<Retained<NSString>>
Available on crate feature objc2-foundation only.
pub unsafe fn nameAsString(&self) -> Option<Retained<NSString>>
objc2-foundation only.Gets the “friendly” name of HCI controller.
Returns: Returns NSString with the device name, nil if there is not one or it cannot be read.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for IOBluetoothHostController
impl AsRef<AnyObject> for IOBluetoothHostController
Sourceimpl AsRef<NSObject> for IOBluetoothHostController
impl AsRef<NSObject> for IOBluetoothHostController
Sourceimpl Borrow<AnyObject> for IOBluetoothHostController
impl Borrow<AnyObject> for IOBluetoothHostController
Sourceimpl Borrow<NSObject> for IOBluetoothHostController
impl Borrow<NSObject> for IOBluetoothHostController
Sourceimpl ClassType for IOBluetoothHostController
impl ClassType for IOBluetoothHostController
Sourceconst NAME: &'static str = "IOBluetoothHostController"
const NAME: &'static str = "IOBluetoothHostController"
Sourcetype ThreadKind = <<IOBluetoothHostController as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<IOBluetoothHostController as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for IOBluetoothHostController
impl Debug for IOBluetoothHostController
Sourceimpl Deref for IOBluetoothHostController
impl Deref for IOBluetoothHostController
Sourceimpl Hash for IOBluetoothHostController
impl Hash for IOBluetoothHostController
Sourceimpl Message for IOBluetoothHostController
impl Message for IOBluetoothHostController
Sourceimpl NSObjectProtocol for IOBluetoothHostController
impl NSObjectProtocol for IOBluetoothHostController
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref