#[repr(C)]pub struct IOBluetoothSDPServiceAttribute { /* private fields */ }IOBluetoothSDPServiceAttribute and objc2 only.Expand description
IOBluetoothSDPServiceAttribute represents a single SDP service attribute.
A service attribute contains two components: an attribute ID and a data element.
See also Apple’s documentation
Implementations
Sourceimpl IOBluetoothSDPServiceAttribute
impl IOBluetoothSDPServiceAttribute
Sourcepub unsafe fn withID_attributeElementValue(
new_attribute_id: BluetoothSDPServiceAttributeID,
attribute_element_value: Option<&NSObject>,
) -> Option<Retained<Self>>
Available on crate feature Bluetooth only.
pub unsafe fn withID_attributeElementValue( new_attribute_id: BluetoothSDPServiceAttributeID, attribute_element_value: Option<&NSObject>, ) -> Option<Retained<Self>>
Bluetooth only.Creates a new service attribute with the given ID and element value.
See +[IOBluetoothSDPDataElement withElementValue:] for a description of the types that may be passed in as the attributeElementValue.
Parameter attributeID: The attribute ID of the new service attribute.
Parameter attributeElementValue: The data element value of the new service attribute
Returns: Returns the newly allocated service attribute object. Returns nil if there was an error parsing the element value. The returned IOBluetoothSDPDataElement object has been autoreleased, so it is not necessary for the caller to release it. If the object is to be referenced and kept around, retain should be called.
Sourcepub unsafe fn withID_attributeElement(
new_attribute_id: BluetoothSDPServiceAttributeID,
attribute_element: Option<&IOBluetoothSDPDataElement>,
) -> Option<Retained<Self>>
Available on crate features Bluetooth and IOBluetoothSDPDataElement only.
pub unsafe fn withID_attributeElement( new_attribute_id: BluetoothSDPServiceAttributeID, attribute_element: Option<&IOBluetoothSDPDataElement>, ) -> Option<Retained<Self>>
Bluetooth and IOBluetoothSDPDataElement only.Creates a new service attribute with the given ID and data element.
Parameter attributeID: The attribute ID of the new service attribute.
Parameter attributeElement: The data element of the new service attribute.
Returns: Returns the newly allocated service attribute object. Returns nil if there was an error. The returned IOBluetoothSDPDataElement object has been autoreleased, so it is not necessary for the caller to release it. If the object is to be referenced and kept around, retain should be called.
Sourcepub unsafe fn initWithID_attributeElementValue(
this: Allocated<Self>,
new_attribute_id: BluetoothSDPServiceAttributeID,
attribute_element_value: Option<&NSObject>,
) -> Option<Retained<Self>>
Available on crate feature Bluetooth only.
pub unsafe fn initWithID_attributeElementValue( this: Allocated<Self>, new_attribute_id: BluetoothSDPServiceAttributeID, attribute_element_value: Option<&NSObject>, ) -> Option<Retained<Self>>
Bluetooth only.Initializes a new service attribute with the given ID and element value.
See +[IOBluetoothSDPDataElement withElementValue:] for a description of the types that may be passed in as the attributeElementValue.
Parameter attributeID: The attribute ID of the new service attribute.
Parameter attributeElementValue: The data element value of the new service attribute
Returns: Returns self if successful. Returns nil if there was an error parsing the element value.
Sourcepub unsafe fn initWithID_attributeElement(
this: Allocated<Self>,
new_attribute_id: BluetoothSDPServiceAttributeID,
attribute_element: Option<&IOBluetoothSDPDataElement>,
) -> Option<Retained<Self>>
Available on crate features Bluetooth and IOBluetoothSDPDataElement only.
pub unsafe fn initWithID_attributeElement( this: Allocated<Self>, new_attribute_id: BluetoothSDPServiceAttributeID, attribute_element: Option<&IOBluetoothSDPDataElement>, ) -> Option<Retained<Self>>
Bluetooth and IOBluetoothSDPDataElement only.Initializes a new service attribute with the given ID and data element.
Parameter attributeID: The attribute ID of the new service attribute.
Parameter attributeElement: The data element of the new service attribute.
Returns: Returns self if successful. Returns nil if there was an error.
Sourcepub unsafe fn getAttributeID(&self) -> BluetoothSDPServiceAttributeID
Available on crate feature Bluetooth only.
pub unsafe fn getAttributeID(&self) -> BluetoothSDPServiceAttributeID
Bluetooth only.Returns the attribute ID for the target service attribute.
Returns: Returns the attribute ID for the target service attribute.
Sourcepub unsafe fn getDataElement(
&self,
) -> Option<Retained<IOBluetoothSDPDataElement>>
Available on crate feature IOBluetoothSDPDataElement only.
pub unsafe fn getDataElement( &self, ) -> Option<Retained<IOBluetoothSDPDataElement>>
IOBluetoothSDPDataElement only.Returns the data element for the target service attribute.
Returns: Returns the data element for the target service attribute.
Sourcepub unsafe fn getIDDataElement(
&self,
) -> Option<Retained<IOBluetoothSDPDataElement>>
Available on crate feature IOBluetoothSDPDataElement only.
pub unsafe fn getIDDataElement( &self, ) -> Option<Retained<IOBluetoothSDPDataElement>>
IOBluetoothSDPDataElement only.Returns the data element representing the attribute ID for the target service attribute.
Returns: Returns the data element representing the attribute ID for the target service attribute.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl ClassType for IOBluetoothSDPServiceAttribute
impl ClassType for IOBluetoothSDPServiceAttribute
Sourceconst NAME: &'static str = "IOBluetoothSDPServiceAttribute"
const NAME: &'static str = "IOBluetoothSDPServiceAttribute"
Sourcetype ThreadKind = <<IOBluetoothSDPServiceAttribute as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<IOBluetoothSDPServiceAttribute as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSObjectProtocol for IOBluetoothSDPServiceAttribute
impl NSObjectProtocol for IOBluetoothSDPServiceAttribute
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref